make_pipeline
==============================================================

.. currentmodule:: imbalanced_ensemble.pipeline

.. autofunction:: make_pipeline

.. include:: ../../../back_references/imbalanced_ensemble.pipeline.make_pipeline.examples

.. raw:: html

    <div style='clear:both'></div>